==> qbittorrent_3.2.3.orig.tar.xz: qbittorrent-3.2.3/src/gui/speedlimitdlg.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2006  Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */

#ifndef BANDWIDTH_ALLOCATION_H
#define BANDWIDTH_ALLOCATION_H

#include <QDialog>
#include <QList>
#include "ui_bandwidth_limit.h"
#include "misc.h"
#include "qbtsession.h"

class SpeedLimitDialog : public QDialog, private Ui_bandwidth_dlg {
    Q_OBJECT
public:
    explicit SpeedLimitDialog(QWidget *parent=0);
    ~SpeedLimitDialog();
    static long askSpeedLimit(bool *ok, QString title, long default_value, long max_value=10240000);

protected slots:
    void updateSpinValue(int val) const;
    void updateSliderValue(int val) const;
    long getSpeedLimit() const;
    void setupDialog(long max_slider, long val) const;
};

#endif

==> qbittorrent_3.3.1.orig.tar.xz: qbittorrent-3.3.1/src/gui/speedlimitdlg.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2006  Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */

#ifndef BANDWIDTH_ALLOCATION_H
#define BANDWIDTH_ALLOCATION_H

#include <QDialog>
#include <QList>
#include "ui_bandwidth_limit.h"
#include "base/utils/misc.h"
#include "base/bittorrent/session.h"

class SpeedLimitDialog : public QDialog, private Ui_bandwidth_dlg {
    Q_OBJECT
public:
    explicit SpeedLimitDialog(QWidget *parent=0);
    ~SpeedLimitDialog();
    static long askSpeedLimit(bool *ok, QString title, long default_value, long max_value=10240000);

protected slots:
    void updateSpinValue(int val) const;
    void updateSliderValue(int val) const;
    long getSpeedLimit() const;
    void setupDialog(long max_slider, long val) const;
};

#endif
